/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.editingsupport;

import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.base.ui.annotation.AnnotationEntry;
import org.fortiss.tooling.base.ui.annotation.view.GenericAnnotationView;
import org.fortiss.tooling.kernel.model.INamedElement;

/**
 * Base class for {@link EditingSupport}s used in the {@link GenericAnnotationView}.
 * 
 * @author barner
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating RED
 */
public class ElementNameEditingSupport extends TextEditingSupport {

	/** Constructs a new {@link ElementNameEditingSupport}. */
	public ElementNameEditingSupport(ColumnViewer viewer) {
		// Specification class is not needed, since the name is stored directly in the model (hence
		// pass {@code null}).
		super(viewer, null, null);
	}

	/** {@inheritDoc} */
	@Override
	protected boolean canEdit(Object element) {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	protected Object doGetValue(AnnotationEntry annotationEntry) {
		IModelElement modelElement = annotationEntry.getModelElement();

		if(modelElement instanceof INamedElement) {
			return ((INamedElement)modelElement).getName();
		}

		return null;
	}

	/** {@inheritDoc} */
	@Override
	protected void doSetValue(AnnotationEntry annotationEntry, String value) throws Exception {
		IModelElement modelElement = annotationEntry.getModelElement();

		if(modelElement instanceof INamedElement) {
			((INamedElement)modelElement).setName(value);
		}
	}
}
