/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.editingsupport;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.TextCellEditor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;

/**
 * This class constructs and manages an editing element for the annotation view. It provides a
 * simple text input field, for the case that not predefined values are given and no custom editing
 * fields are defined.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 09C91FA1AB55052CD74ECF69E121DD7C
 */
public class TextEditingSupport extends AnnotationEditingSupportBase {

	/** Text cell editor */
	protected TextCellEditor cellEditor = null;

	/** Constructor. */
	public TextEditingSupport(ColumnViewer viewer,
			Class<? extends IAnnotatedSpecification> specClass, String instanceKey) {
		super(viewer, specClass, instanceKey);

		cellEditor = new TextCellEditor((Composite)getViewer().getControl(), SWT.NONE);
	}

	/** {@inheritDoc} */
	@Override
	protected CellEditor getCellEditor(Object element) {
		return cellEditor;
	}

	/** {@inheritDoc} */
	@Override
	protected Object getValue(Object element) {
		// This method is triggered from several methods in EditingSupport, which - for this
		// TextEditingSupport - passes its result to TextCellEditor.doSetValue() which expects a
		// non-null String.
		Object rval = super.getValue(element);
		if(rval != null) {
			return rval.toString();
		}

		return "";
	}
}
