/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui.util;

import static org.fortiss.tooling.graphicsGL.ToolingGraphicsGLActivator.PLUGIN_ID;
import static org.fortiss.tooling.graphicsGL.ui.ToolingGraphicsGLUIActivator.getDefault;
import static org.fortiss.tooling.kernel.utils.LoggingUtils.error;
import static org.fortiss.tooling.kernel.utils.ResourceUtils.getStringContentFromResource;

import java.util.HashMap;
import java.util.List;

import org.fortiss.tooling.graphicsGL.model.Positioned3DBase;
import org.fortiss.tooling.graphicsGL.model.scene.Object3D;
import org.fortiss.tooling.graphicsGL.util.OBJLoaderUtil;
import org.lwjgl.util.vector.Vector3f;

/**
 * Utility class for representing 3D Objects (letters, characters, numbers)
 * 
 * @author eder
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: A11A1531BD9D31989E82A8FE950F1082
 */
public class Graph3DUtil {

	/** Array of letters which can be rendered */
	public static final char[] LETTERS = {'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K',
			'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z'};
	/** Array of special characters which can be rendered */
	public static final char[] CHARACTERS = {'?'};
	/** Array of numbers which can be rendered */
	public static final int[] NUMBERS = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};

	/** Converts a Positioned3DBase Vector in a Vector3f */
	public static Vector3f convert(Positioned3DBase pos) {
		return new Vector3f(pos.getPosition().getX(), pos.getPosition().getY(), pos.getPosition()
				.getZ());
	}

	/** Returns a hash map with letter to Object3D mapping */
	public static HashMap<String, Object3D> importLetters() {
		HashMap<String, Object3D> mapping = new HashMap<String, Object3D>();

		for(char l : LETTERS) {
			String path = "/data/letters/" + l;
			Object3D o = getObject(path);
			String key = "" + l;
			mapping.put(key, o);
		}

		return mapping;
	}

	/** Returns a hash map with character to Object3D mapping */
	public static HashMap<String, Object3D> importCharacters() {
		HashMap<String, Object3D> mapping = new HashMap<String, Object3D>();

		for(char l : CHARACTERS) {
			String filename = charToString(l);
			String path = "/data/characters/" + filename;
			Object3D o = getObject(path);
			String key = "" + l;
			mapping.put(key, o);
		}

		return mapping;
	}

	/** Returns a hash map with character to Object3D mapping */
	public static HashMap<Integer, Object3D> importNumbers() {
		HashMap<Integer, Object3D> mapping = new HashMap<Integer, Object3D>();

		for(int l : NUMBERS) {
			String filename = intToString(l);
			String path = "/data/numbers/" + filename;
			Object3D o = getObject(path);
			mapping.put(l, o);
		}

		return mapping;
	}

	/** Returns the string related to the given character */
	private static String charToString(char c) {
		switch(c) {
			case '?':
				return "QuestionMark";
			default:
				return "QuestionMark";
		}
	}

	/** Returns the string related to the given integer */
	private static String intToString(int i) {
		switch(i) {
			case 0:
				return "zero";
			case 1:
				return "one";
			case 2:
				return "two";
			case 3:
				return "three";
			case 4:
				return "four";
			case 5:
				return "five";
			case 6:
				return "six";
			case 7:
				return "seven";
			case 8:
				return "eight";
			case 9:
				return "nine";
			default:
				return "zero";
		}
	}

	/** Returns the object loaded from the given path. */
	private static Object3D getObject(String modelPath) {
		try {
			List<String> objData = getStringContentFromResource(PLUGIN_ID, modelPath + ".obj");
			List<String> mtlData = getStringContentFromResource(PLUGIN_ID, modelPath + ".mtl");

			return new OBJLoaderUtil(objData, mtlData).getLoadedObjects().get(0);
		} catch(Exception ex) {
			error(getDefault(), ex.getMessage(), ex);
		}
		return null;
	}
}
