/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.base;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.IConstraintChecker;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;

/**
 * Base implementation for {@link IConstraintChecker}. It checks the model
 * element against null and returns an unmodifiable empty list.
 * 
 * @param <T>
 *            the model element class for elements to be checked by this
 *            constraint checker.
 * @param <V>
 *            the model element class of violating elements. Use {@link EObject} as parameter value
 *            if you need multiple classes here.
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 943370276B5CAA913FFAE7DAE0627B27
 */
public abstract class MultiViolationConstraintCheckerBase<T extends EObject, V extends EObject>
		extends ConstraintCheckerBase<T> {

	/** {@inheritDoc} */
	@Override
	public final List<? extends IConstraintViolation<V>> apply(T modelElement) {
		List<IConstraintViolation<V>> results = new ArrayList<IConstraintViolation<V>>();
		collectViolations(modelElement, results);
		return results.isEmpty() ? null : results;
	}

	/** Collects the violations in the given result lists. */
	protected abstract void
			collectViolations(T modelElement, List<IConstraintViolation<V>> results);
}
