/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import java.util.List;

import org.fortiss.tooling.kernel.extension.ITransformationProvider;
import org.fortiss.tooling.kernel.extension.data.ITransformationContext;
import org.fortiss.tooling.kernel.extension.data.TransformationProviderChain;
import org.fortiss.tooling.kernel.extension.exception.TransformationFailedException;
import org.fortiss.tooling.kernel.internal.TransformationService;

/**
 * The transformation service provides registration and access to transformation
 * providers. A transformation provider knows how to transform a given source
 * object into an instance of a given target class using the provided context
 * information.
 * 
 * @see ITransformationProvider
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 1A3F5C9BB18ACEB99A11FDC5321D3CA7
 */
public interface ITransformationService {

	/** Returns the singleton instance of the service. */
	public static final ITransformationService INSTANCE = new TransformationService();

	/**
	 * Determines if there is a transformation provider, which can perform the
	 * transformation of the given source element into the given target element.
	 */
	boolean canTransform(Object source, Class<?> targetClass, ITransformationContext context);

	/**
	 * Returns the transformation result using a suitable transformation
	 * provider.
	 * 
	 * @throws TransformationFailedException
	 *             if something goes wrong during the transformation.
	 */
	Object transform(Object source, Class<?> targetClass, ITransformationContext context)
			throws TransformationFailedException;

	/**
	 * Returns all chains of transformation providers for the given source class
	 * to target class transformation. Never returns <code>null</code>, but an
	 * empty list.
	 */
	List<TransformationProviderChain> getTransformationProviderChain(Class<?> sourceClass,
			Class<?> targetClass, ITransformationContext context);
}
