/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.action;

import org.conqat.ide.commons.ui.swt.ClipboardUtils;
import org.eclipse.jface.action.Action;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Text;

/**
 * A paste action that is aware of text controls. If a text control has the
 * focus, the {@link Text#paste()} is performed, otherwise the subclass can
 * decide where to paste the text.
 * 
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 7C35C78B8CCF5EAF1E9380B0B9340B41
 */
public abstract class TextAwarePasteAction extends Action {

	/** {@inheritDoc} */
	@Override
	public void run() {
		Control focusControl = Display.getCurrent().getFocusControl();
		if (focusControl instanceof Text) {
			((Text) focusControl).paste();
		} else {
			String contents = ClipboardUtils.getContents();
			if (contents != null) {
				performPaste(contents);
			}
		}
	}

	/** Template method that pastes the given text. */
	protected abstract void performPaste(String contents);
}