/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.editor;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.resources.IResourceChangeListener;
import org.eclipse.core.resources.IResourceDelta;
import org.eclipse.core.resources.IResourceDeltaVisitor;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.ui.IEditorPart;

/**
 * Listener used in
 * {@link EditorUtils#makeEditorResourceAware(IEditorPart, IFile)}. This closes
 * the editor as soon as the watched file is removed.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: EE8E7A57E7B6B6DAC46B10F744E0EB5E
 */
/* package */class CloseEditorOnFileRemovedListener implements
		IResourceChangeListener, IResourceDeltaVisitor {

	/** The editor to be closed. */
	private IEditorPart editor;

	/** The file monitored for deletion. */
	private IFile file;

	/** Constructor. */
	public CloseEditorOnFileRemovedListener(IEditorPart editor, IFile file) {
		this.editor = editor;
		this.file = file;
	}

	/** {@inheritDoc} */
	@Override
	public void resourceChanged(IResourceChangeEvent event) {
		try {
			event.getDelta().accept(this);
		} catch (CoreException e) {
			// we just ignore this here; worst thing that can happen is that the
			// editor is not closed. Chances are however, that the exception
			// does not even affect the file we are looking for.
		}
	}

	/** {@inheritDoc} */
	@Override
	public boolean visit(IResourceDelta delta) {
		if (file.equals(delta.getResource())
				&& delta.getKind() == IResourceDelta.REMOVED) {

			editor.getSite().getShell().getDisplay().asyncExec(new Runnable() {
				@Override
				public void run() {
					editor.getEditorSite().getPage().closeEditor(editor, false);
				}
			});
			return false;
		}
		return true;
	}
}