/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.lib.commons.assessment;

import java.awt.Color;

import org.conqat.lib.commons.color.ECCSMColor;

/**
 * Enum for traffic light colors.
 * 
 * Note that the order is relevant: The first Color (RED) is considered the most
 * dominant color (see {@link Assessment#getDominantColor()}).
 * 
 * @author $Author: deissenb $
 * @version $Rev: 35954 $
 * @ConQAT.Rating GREEN Hash: C62972EE424474E2A5821B01FD309AE7
 */
public enum ETrafficLightColor {
	/** Red signals errors or incomleteness. */
	RED(ECCSMColor.RED),

	/** Yellow signals warning or lack of control. */
	YELLOW(ECCSMColor.YELLOW),

	/** Green signals the absence of errors or correctness. */
	GREEN(ECCSMColor.GREEN),

	/**
	 * Baseline indicates a baseline entry, i.e. there has been no change
	 * compared to a given baseline and thus no color applies.
	 */
	BASELINE(ECCSMColor.LIGHT_BLUE),

	/** This is used if no information is available. */
	UNKNOWN(ECCSMColor.DARK_GRAY);

	/** The associated color. */
	private Color color;

	/** Constructor. */
	private ETrafficLightColor(ECCSMColor color) {
		this.color = color.getColor();
	}

	/** Returns the AWT color representing this. */
	public Color getColor() {
		return color;
	}

	/**
	 * Returns the more dominant color, which is the enum literal with smaller
	 * index (as they are sorted by dominance). 
	 */
	public static ETrafficLightColor getDominantColor(
			ETrafficLightColor color1, ETrafficLightColor color2) {
		if (color2.ordinal() < color1.ordinal()) {
			return color2;
		}
		return color1;
	}
}